@@ -1,14 +1,14 @@
 import json
 
-from netbox import NetBoxClient
 import pynetbox
+from netbox import NetBoxClient
 
 nb = NetBoxClient(
     base_url="http://127.0.0.1:8000/", token="1dc6fa5bfcef8390dd83a261c36ed8f1551b2d6b"
 )
 
 pynb = pynetbox.api(
-    'http://127.0.0.1:8000/', token='1dc6fa5bfcef8390dd83a261c36ed8f1551b2d6b'
+    "http://127.0.0.1:8000/", token="1dc6fa5bfcef8390dd83a261c36ed8f1551b2d6b"
 )
 
 # 1. List
